# YouTube NewsBoat RSS CLI


This CLI will add the correct YouTube RSS videos feeder to [NewsBoat](https://bit.ly/4ehNsOr) urls for you.

## Simple Docs

Pass in a YouTube videos url and it will add the correct RSS feed to
newsboat.

**Usage**:

```console
$ main [OPTIONS] URLS...
```

**Arguments**:

* `URLS...`: [required]

**Options**:

* `--install-completion`: Install completion for the current shell.
* `--show-completion`: Show completion for the current shell, to copy it or customize the installation.
* `--help`: Show this message and exit.
